########################################################################################

#This script is an online supplement to the paper:

#The impact of situational test anxiety on retest effects in cognitive
#ability testing: A structural equation modeling approach (Jendryczko, Scharfen and Holling)

#It proceeds with all the data analyses of the paper and the electronical supplement
#"Suplementary_Analyses.docx" and gives additional insights into models.

#You will need the data file "Data.rda" as well.

########################################################################################


######

###

#0. load packages and the data

###

library(psych)
library(Hmisc)
library(ltm)
library(lavaan)

load("Data.rda")
#all_data_subset represents the data of the main study where participants with ceilling effects were
#excluded from the analysis (N =225).
#all_data still contains these participants and is analyzed in Appendix B (N=276). 
#all_data_ha exclusively contains these participants with ceiling effects (high achievers = ha; N=51).
#The three data sets only differ with regards to participants (rows).
#They contain the same variables (columns).

#a rundun of variables:
names(all_data_subset)
#matrix_sum_x: These variables describe matrix sum scores for test session x (1 to 7)
#i_1_y_x: These variables describe matrix item y (1 to 13) to test session x
#fam_M_x: These variables describe fear of failure (fof; subscale of the FAM) sum scores to test session x
#fam_y_x: These variables describe one of the 5 fof-items (y = either 5; 9; 12; 16 or 18) to time x.

#Since in some models a very large amount of parameters is estimated, you will
#have to increase the amount of characters R prints on a single prompt by default:
options(max.print = 1000000000)

#We also recommend that you gather the information in a seperate text file.
#The outputs of some of the larger models might not be completely visible otherwise.
#If you do not to wish to do this, do not run the next three commands:

#create the text file "analysis_results" that will contain analysis results:
zz <- file("analysis_results.txt", open = "wt")
#specify that you want the outputs printed in that file
sink(zz ,type = "output")
#specify that you also want warning messages printed in that file
sink(zz, type = "message")


#############################

### main study: analysis of all_data_subset

#############################


###

#1. descriptive statistics

###

#1.1 univariate statistics of matrices sum scores:
mean(all_data_subset$matrix_sum_1);sd(all_data_subset$matrix_sum_1);min(all_data_subset$matrix_sum_1);max(all_data_subset$matrix_sum_1)
mean(all_data_subset$matrix_sum_2);sd(all_data_subset$matrix_sum_2);min(all_data_subset$matrix_sum_2);max(all_data_subset$matrix_sum_2)
mean(all_data_subset$matrix_sum_3);sd(all_data_subset$matrix_sum_3);min(all_data_subset$matrix_sum_3);max(all_data_subset$matrix_sum_3)
mean(all_data_subset$matrix_sum_4);sd(all_data_subset$matrix_sum_4);min(all_data_subset$matrix_sum_4);max(all_data_subset$matrix_sum_4)
mean(all_data_subset$matrix_sum_5);sd(all_data_subset$matrix_sum_5);min(all_data_subset$matrix_sum_5);max(all_data_subset$matrix_sum_5)
mean(all_data_subset$matrix_sum_6);sd(all_data_subset$matrix_sum_6);min(all_data_subset$matrix_sum_6);max(all_data_subset$matrix_sum_6)
mean(all_data_subset$matrix_sum_7);sd(all_data_subset$matrix_sum_7);min(all_data_subset$matrix_sum_7);max(all_data_subset$matrix_sum_7)

#1.2. internal consistencies of matrices items
cronbach.alpha(all_data_subset[,c("i_1_1_1", "i_1_2_1", "i_1_3_1", "i_1_4_1", "i_1_5_1", "i_1_6_1", "i_1_7_1"
                                  , "i_1_8_1", "i_1_9_1", "i_1_10_1", "i_1_11_1", "i_1_12_1", "i_1_13_1")])
cronbach.alpha(all_data_subset[,c("i_1_1_2", "i_1_2_2", "i_1_3_2", "i_1_4_2", "i_1_5_2", "i_1_6_2", "i_1_7_2"
                                  , "i_1_8_2", "i_1_9_2", "i_1_10_2", "i_1_11_2", "i_1_12_2", "i_1_13_2")])
cronbach.alpha(all_data_subset[,c("i_1_1_3", "i_1_2_3", "i_1_3_3", "i_1_4_3", "i_1_5_3", "i_1_6_3", "i_1_7_3"
                                  , "i_1_8_3", "i_1_9_3", "i_1_10_3", "i_1_11_3", "i_1_12_3", "i_1_13_3")])
cronbach.alpha(all_data_subset[,c("i_1_1_4", "i_1_2_4", "i_1_3_4", "i_1_4_4", "i_1_5_4", "i_1_6_4", "i_1_7_4"
                                  , "i_1_8_4", "i_1_9_4", "i_1_10_4", "i_1_11_4", "i_1_12_4", "i_1_13_4")])
cronbach.alpha(all_data_subset[,c("i_1_1_5", "i_1_2_5", "i_1_3_5", "i_1_4_5", "i_1_5_5", "i_1_6_5", "i_1_7_5"
                                  , "i_1_8_5", "i_1_9_5", "i_1_10_5", "i_1_11_5", "i_1_12_5", "i_1_13_5")])
cronbach.alpha(all_data_subset[,c("i_1_1_6", "i_1_2_6", "i_1_3_6", "i_1_4_6", "i_1_5_6", "i_1_6_6", "i_1_7_6"
                                  , "i_1_8_6", "i_1_9_6", "i_1_10_6", "i_1_11_6", "i_1_12_6", "i_1_13_6")])
cronbach.alpha(all_data_subset[,c("i_1_1_7", "i_1_2_7", "i_1_3_7", "i_1_4_7", "i_1_5_7", "i_1_6_7", "i_1_7_7"
                                  , "i_1_8_7", "i_1_9_7", "i_1_10_7", "i_1_11_7", "i_1_12_7", "i_1_13_7")])

#1.3. univariate descriptive statistics of fof sum scores
mean(all_data_subset$fam_M_1);sd(all_data_subset$fam_M_1);min(all_data_subset$fam_M_1);max(all_data_subset$fam_M_1)
mean(all_data_subset$fam_M_2);sd(all_data_subset$fam_M_2);min(all_data_subset$fam_M_2);max(all_data_subset$fam_M_2)
mean(all_data_subset$fam_M_3);sd(all_data_subset$fam_M_3);min(all_data_subset$fam_M_3);max(all_data_subset$fam_M_3)
mean(all_data_subset$fam_M_4);sd(all_data_subset$fam_M_4);min(all_data_subset$fam_M_4);max(all_data_subset$fam_M_4)
mean(all_data_subset$fam_M_5);sd(all_data_subset$fam_M_5);min(all_data_subset$fam_M_5);max(all_data_subset$fam_M_5)
mean(all_data_subset$fam_M_6);sd(all_data_subset$fam_M_6);min(all_data_subset$fam_M_6);max(all_data_subset$fam_M_6)
mean(all_data_subset$fam_M_7);sd(all_data_subset$fam_M_7);min(all_data_subset$fam_M_7);max(all_data_subset$fam_M_7)

#1.4. internal consistencies of fof sum scores
cronbach.alpha(all_data_subset[,c("fam_5_1", "fam_9_1" , "fam_12_1" , "fam_16_1" , "fam_18_1")])
cronbach.alpha(all_data_subset[,c("fam_5_2", "fam_9_2" , "fam_12_2" , "fam_16_2" , "fam_18_2")])
cronbach.alpha(all_data_subset[,c("fam_5_3", "fam_9_3" , "fam_12_3" , "fam_16_3" , "fam_18_3")])
cronbach.alpha(all_data_subset[,c("fam_5_4", "fam_9_4" , "fam_12_4" , "fam_16_4" , "fam_18_4")])
cronbach.alpha(all_data_subset[,c("fam_5_5", "fam_9_5" , "fam_12_5" , "fam_16_5" , "fam_18_5")])
cronbach.alpha(all_data_subset[,c("fam_5_6", "fam_9_6" , "fam_12_6" , "fam_16_6" , "fam_18_6")])
cronbach.alpha(all_data_subset[,c("fam_5_7", "fam_9_7" , "fam_12_7" , "fam_16_7" , "fam_18_7")])


#1.5. correlations of score variables:
#correlation matrix:
round(cor(all_data_subset[,c("matrix_sum_1","matrix_sum_2","matrix_sum_3","matrix_sum_4",
                             "matrix_sum_5","matrix_sum_6","matrix_sum_7", 
                             "fam_M_1","fam_M_2","fam_M_3","fam_M_4",
                             "fam_M_5","fam_M_6","fam_M_7")]),3)
#p-values for correlations:
rcorr(as.matrix(all_data_subset[,c("matrix_sum_1","matrix_sum_2","matrix_sum_3","matrix_sum_4",
                                   "matrix_sum_5","matrix_sum_6","matrix_sum_7", 
                                   "fam_M_1","fam_M_2","fam_M_3","fam_M_4",
                                   "fam_M_5","fam_M_6","fam_M_7")]))

#1.6 A little extra: suggested code for assessing descriptive statistics of all data set variables quickly:
#univariate:
apply(all_data_subset, 2, FUN = psych::describe)
#multivariate (correlations)
cor(all_data_subset)

#1.7. A little extra: tetrachoric correlations for the binary matrices items:
tetrachoric(all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))])
#Note: Due to empty cells in the 2x2 table of some item couples, the matrix is not positive definite.
#This is to be expected in longitudinal studies when particularly easy/difficult items
#(or parallel versions of these) are presented repeatedly.
#Similar warnings will accordingly emerge for the SEMs as well.
#Further investigation of model parameters and standard errors will however reveal no alarming results.

###

#2. ability-CFA

###

#2.1. prepare data: set matrices items as ordinal 
all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))] <- 
  lapply(all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))], ordered)

#2.2. measurement invariance: model estimations and comparisons:

#covarianc matrix of latent variables is not positive-definite for all ability-CFA.
#Investigations on the correlations reveal that there are some very high correlations (> .95).
#However models converged properly and high correlations are to be expected (see above)
#especially when the tests are rather easy, the ability is assumed to be very stable
#and such a large number of measurement occasions are implmented.
#
#This explanation apply to the respective analyses with the complete sample (N=276) as well (see below).

###configural
configural<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7
'

configural_fit<-sem(configural, data= all_data_subset, std.lv=F)
summary(configural_fit, fit.measures=T, standardized=T)


###weak

weak <-'

e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1

e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2

e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3

e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4

e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5

e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6

e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7
'

weak_fit<-sem(weak, data= all_data_subset, std.lv=F)
summary(weak_fit, fit.measures=T, standardized=T)



###strong

#An additional warning will emerge:
# 1: In lav_model_vcov(lavmodel = lavmodel, lavsamplestats = lavsamplestats,  :
#                        lavaan WARNING:
#                        The variance-covariance matrix of the estimated parameters (vcov)
#                      does not appear to be positive definite!
#This is to be expected in longitudinal studies when particularly easy/difficult items
#(or parallel versions of these) are presented repeatedly and difficulty restrictions are 
#implemented (see above). However a further investigation reveals no completely unreasonable
#fit statistic, parameter-estimate or standard error. Moreover, the model is indeed identified
#as standard errors were produced and a repeated estimation will lead to the same results.
#
#This explanation will also hold true for the estimation of this model in the complete sample
#(N = 276)

strong<-'

e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1

e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2

e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3

e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4

e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5

e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6

e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#thresholds
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1

#means of latent variables
e1~1
e2~1
e3~1
e4~1
e5~1
e6~1
e7~1
'

strong_fit<-sem(strong, data= all_data_subset, std.lv=F)
summary(strong_fit, fit.measures=T, standardized=T)

#2.3. comparisons via likelihood ratio tests
lrtests <- anova(configural_fit, weak_fit, strong_fit)
lrtests


###

#3. STA-CFA

###

#3.1. configural
fof_c <- '
fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

#specify the indicator specific latent variables to account for item specific covariances:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify model latent variable correlations:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
'
fof_c_fit <- sem(fof_c, data= all_data_subset, estimator= "MLR", std.lv=F)
summary(fof_c_fit, standardized=T, fit.measures=T)


#3.2. weak
fof_w <- '
fof1 =~ a*fam_5_1 + b*fam_9_1 + c*fam_12_1 + d*fam_16_1 + e*fam_18_1 
fof2 =~ a*fam_5_2 + b*fam_9_2 + c*fam_12_2 + d*fam_16_2 + e*fam_18_2 
fof3 =~ a*fam_5_3 + b*fam_9_3 + c*fam_12_3 + d*fam_16_3 + e*fam_18_3 
fof4 =~ a*fam_5_4 + b*fam_9_4 + c*fam_12_4 + d*fam_16_4 + e*fam_18_4 
fof5 =~ a*fam_5_5 + b*fam_9_5 + c*fam_12_5 + d*fam_16_5 + e*fam_18_5 
fof6 =~ a*fam_5_6 + b*fam_9_6 + c*fam_12_6 + d*fam_16_6 + e*fam_18_6 
fof7 =~ a*fam_5_7 + b*fam_9_7 + c*fam_12_7 + d*fam_16_7 + e*fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
'
fof_w_fit <- sem(fof_w, data= all_data_subset, estimator= "MLR", std.lv =F)
summary(fof_w_fit, standardized=T, fit.measures=T)

#3.3. comparison via likelihood ratio test:
anova(fof_c_fit, fof_w_fit)


###

#4. interference reduction approach

###

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

#Warning: This analysis requires a lot of time and pc memory capacity. It might take up to 24 hours.
#Since the created lavaan-specific objects take up a lot of RAM, they will be frequently saved (via "save-image")
#and removed (via "rm") from workspace.
#It is highly recommended to save analysis results in a seperate text file, if you are not already doing so 
#(see beginning of script).:

# #create the text file "analysis_results" that will contain analysis results:
# zz <- file("analysis_results.txt", open = "wt")
# #specify that you want the outputs printed in that file
# sink(zz ,type = "output")
# #specify that you also want warning messages printed in that file
# sink(zz, type = "message")

#Some explanations:
#induce describes the complete interference model where interference effects induce measurement bias at every testsesison.
#Retest effects that are graphically displayed in the article are taken from this model.
#inducex describes a more parsimonious interference model where interferences are only modeled up to test session x (1 to 6).
#induce0 discribes a model with only deficit but no interference effects.
#lr_induce_xy describes the likelihood ratio test between a model where interferences are modeled up to
#testsession x and a more parsimonious model where interference effects are only modeled up to testsession y = x-1.

#Again, warnings will emerge for all models.
# 1: In lav_model_vcov(lavmodel = lavmodel, lavsamplestats = lavsamplestats,  :
#                        lavaan WARNING:
#                        The variance-covariance matrix of the estimated parameters (vcov)
#                      does not appear to be positive definite!
#This can happen, when a model contains such a large amount of paramters and is estimated
#with such a small sample size. Models still converged smoothly and are - in fact - identified
#as re-estimation will always deliver the same results and standard errors can be computed
#for all model parameters.
#
# 2: In lav_object_post_check(object) :
#   lavaan WARNING: covariance matrix of latent variables
#   is not positive definite;
#   use lavInspect(fit, "cov.lv") to investigate
#Again, high correlations emerge for the ability states, but these are not alarming (see Ability-CFA above).
#Also, some correlations of the fof-states are very high. The correlation between fof2 and fof3
#slightly exceeds 1 in all cases (1.00 < correlation < 1.03). With regard to its standard error
# (always around 0.07) its confidence intervall still expands substantially below 1 and a high
#correlation of latent variables is expected based on the high correlation of fof sum scores
#alone (see Table 1). Again, the model converged properly and no completely unreasonable
#fit statistics, estimates or standard errors emerged.
#
#Further: Some "NaN" or "Inf" are printed in the coloumns "Std.lv" and "Std.all". These always
#relate to correlations were one of the latent variables e2-e7 are involved. 
#This must be due to technical reasons, since lavaan seems to compute covariances of the
#latent residual variables .e2-.e7 in these cases, which are set to 0 by model definition.
#The first column correctly reports the covariances for the standardized original latent variables
#(as opposed to their residuals). 
#
#All of the above explanations hold true for the analysis with the complete sample (N=276) as well (see below).

induce<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 + i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 + i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 + i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce_fit<-sem(induce, data= all_data_subset, std.lv=T)
summary(induce_fit, fit.measures=T, standardized=T)


induce6<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 + i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 + i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce6_fit<-sem(induce6, data= all_data_subset, std.lv=T)
summary(induce6_fit, fit.measures=T, standardized=T)

lr_induce_76 <- anova(induce_fit, induce6_fit)
lr_induce_76


induce5<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 + i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce5_fit<-sem(induce5, data= all_data_subset, std.lv=T)
summary(induce5_fit, fit.measures=T, standardized=T)

lr_induce_65 <- anova(induce6_fit, induce5_fit)
lr_induce_65

save.image("until5.rda")
rm("induce6_fit")


induce4<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce4_fit<-sem(induce4, data= all_data_subset, std.lv=T)
summary(induce4_fit, fit.measures=T, standardized=T)

lr_induce_54 <- anova(induce5_fit, induce4_fit)
lr_induce_54

save.image("until4.rda")
rm("induce5_fit")


induce3<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce3_fit<-sem(induce3, data= all_data_subset, std.lv=T)
summary(induce3_fit, fit.measures=T, standardized=T)

lr_induce_43 <- anova(induce4_fit, induce3_fit)
lr_induce_43

save.image("until3.rda")
rm("induce4_fit")


induce2<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce2_fit<-sem(induce2, data= all_data_subset, std.lv=T)
summary(induce2_fit, fit.measures=T, standardized=T)

lr_induce_32 <- anova(induce3_fit, induce2_fit)
lr_induce_32

save.image("until2.rda")
rm("induce3_fit")


induce1<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce1_fit<-sem(induce1, data= all_data_subset, std.lv=T)
summary(induce1_fit, fit.measures=T, standardized=T)

lr_induce_21 <- anova(induce2_fit, induce1_fit)
lr_induce_21

save.image("until1.rda")
rm("induce2_fit")


induce0<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce0_fit<-sem(induce0, data= all_data_subset, std.lv=T)
summary(induce0_fit, fit.measures=T, standardized=T)

lr_induce_10 <- anova(induce1_fit, induce0_fit)
lr_induce_10


save.image("until0.rda")



#####################################################################################################################
#####################################################################################################################

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#Before proceeding with the analyses given in Appendix B, you should clear your workspace and reload the data again:
rm(list=ls())
load("Data.rda")


#############################

### Appendix B: the same analyses applied to the complete data set including participants with ceiling effects (N=276)

#############################


###

#1. descriptive statistics

###

#1.1 univariate statistics of matrices sum scores:
mean(all_data$matrix_sum_1);sd(all_data$matrix_sum_1);min(all_data$matrix_sum_1);max(all_data$matrix_sum_1)
mean(all_data$matrix_sum_2);sd(all_data$matrix_sum_2);min(all_data$matrix_sum_2);max(all_data$matrix_sum_2)
mean(all_data$matrix_sum_3);sd(all_data$matrix_sum_3);min(all_data$matrix_sum_3);max(all_data$matrix_sum_3)
mean(all_data$matrix_sum_4);sd(all_data$matrix_sum_4);min(all_data$matrix_sum_4);max(all_data$matrix_sum_4)
mean(all_data$matrix_sum_5);sd(all_data$matrix_sum_5);min(all_data$matrix_sum_5);max(all_data$matrix_sum_5)
mean(all_data$matrix_sum_6);sd(all_data$matrix_sum_6);min(all_data$matrix_sum_6);max(all_data$matrix_sum_6)
mean(all_data$matrix_sum_7);sd(all_data$matrix_sum_7);min(all_data$matrix_sum_7);max(all_data$matrix_sum_7)

#1.2. internal consistencies of matrices items
cronbach.alpha(all_data[,c("i_1_1_1", "i_1_2_1", "i_1_3_1", "i_1_4_1", "i_1_5_1", "i_1_6_1", "i_1_7_1"
                           , "i_1_8_1", "i_1_9_1", "i_1_10_1", "i_1_11_1", "i_1_12_1", "i_1_13_1")])
cronbach.alpha(all_data[,c("i_1_1_2", "i_1_2_2", "i_1_3_2", "i_1_4_2", "i_1_5_2", "i_1_6_2", "i_1_7_2"
                           , "i_1_8_2", "i_1_9_2", "i_1_10_2", "i_1_11_2", "i_1_12_2", "i_1_13_2")])
cronbach.alpha(all_data[,c("i_1_1_3", "i_1_2_3", "i_1_3_3", "i_1_4_3", "i_1_5_3", "i_1_6_3", "i_1_7_3"
                           , "i_1_8_3", "i_1_9_3", "i_1_10_3", "i_1_11_3", "i_1_12_3", "i_1_13_3")])
cronbach.alpha(all_data[,c("i_1_1_4", "i_1_2_4", "i_1_3_4", "i_1_4_4", "i_1_5_4", "i_1_6_4", "i_1_7_4"
                           , "i_1_8_4", "i_1_9_4", "i_1_10_4", "i_1_11_4", "i_1_12_4", "i_1_13_4")])
cronbach.alpha(all_data[,c("i_1_1_5", "i_1_2_5", "i_1_3_5", "i_1_4_5", "i_1_5_5", "i_1_6_5", "i_1_7_5"
                           , "i_1_8_5", "i_1_9_5", "i_1_10_5", "i_1_11_5", "i_1_12_5", "i_1_13_5")])
cronbach.alpha(all_data[,c("i_1_1_6", "i_1_2_6", "i_1_3_6", "i_1_4_6", "i_1_5_6", "i_1_6_6", "i_1_7_6"
                           , "i_1_8_6", "i_1_9_6", "i_1_10_6", "i_1_11_6", "i_1_12_6", "i_1_13_6")])
cronbach.alpha(all_data[,c("i_1_1_7", "i_1_2_7", "i_1_3_7", "i_1_4_7", "i_1_5_7", "i_1_6_7", "i_1_7_7"
                           , "i_1_8_7", "i_1_9_7", "i_1_10_7", "i_1_11_7", "i_1_12_7", "i_1_13_7")])

#1.3. univariate descriptive statistics of fof sum scores
mean(all_data$fam_M_1);sd(all_data$fam_M_1);min(all_data$fam_M_1);max(all_data$fam_M_1)
mean(all_data$fam_M_2);sd(all_data$fam_M_2);min(all_data$fam_M_2);max(all_data$fam_M_2)
mean(all_data$fam_M_3);sd(all_data$fam_M_3);min(all_data$fam_M_3);max(all_data$fam_M_3)
mean(all_data$fam_M_4);sd(all_data$fam_M_4);min(all_data$fam_M_4);max(all_data$fam_M_4)
mean(all_data$fam_M_5);sd(all_data$fam_M_5);min(all_data$fam_M_5);max(all_data$fam_M_5)
mean(all_data$fam_M_6);sd(all_data$fam_M_6);min(all_data$fam_M_6);max(all_data$fam_M_6)
mean(all_data$fam_M_7);sd(all_data$fam_M_7);min(all_data$fam_M_7);max(all_data$fam_M_7)

#1.4. internal consistencies of fof sum scores
cronbach.alpha(all_data[,c("fam_5_1", "fam_9_1" , "fam_12_1" , "fam_16_1" , "fam_18_1")])
cronbach.alpha(all_data[,c("fam_5_2", "fam_9_2" , "fam_12_2" , "fam_16_2" , "fam_18_2")])
cronbach.alpha(all_data[,c("fam_5_3", "fam_9_3" , "fam_12_3" , "fam_16_3" , "fam_18_3")])
cronbach.alpha(all_data[,c("fam_5_4", "fam_9_4" , "fam_12_4" , "fam_16_4" , "fam_18_4")])
cronbach.alpha(all_data[,c("fam_5_5", "fam_9_5" , "fam_12_5" , "fam_16_5" , "fam_18_5")])
cronbach.alpha(all_data[,c("fam_5_6", "fam_9_6" , "fam_12_6" , "fam_16_6" , "fam_18_6")])
cronbach.alpha(all_data[,c("fam_5_7", "fam_9_7" , "fam_12_7" , "fam_16_7" , "fam_18_7")])

#1.5. correlations of score variables:
#correlation matrix:
round(cor(all_data[,c("matrix_sum_1","matrix_sum_2","matrix_sum_3","matrix_sum_4",
                      "matrix_sum_5","matrix_sum_6","matrix_sum_7", 
                      "fam_M_1","fam_M_2","fam_M_3","fam_M_4",
                      "fam_M_5","fam_M_6","fam_M_7")]),3)
#p-values for correlations:
rcorr(as.matrix(all_data[,c("matrix_sum_1","matrix_sum_2","matrix_sum_3","matrix_sum_4",
                            "matrix_sum_5","matrix_sum_6","matrix_sum_7", 
                            "fam_M_1","fam_M_2","fam_M_3","fam_M_4",
                            "fam_M_5","fam_M_6","fam_M_7")]))

#1.6 A little extra: suggested code for assessing descriptive statistics of all data set variables quickly:
#univariate:
apply(all_data, 2, FUN = psych::describe)
#multivariate (correlations)
cor(all_data)

#1.7. A little extra: tetrachoric correlations for the binary matrices items:
tetrachoric(all_data[,c(grep("\\i_1_",names(all_data),val=T))])
#Note: Due to empty cells in the 2x2 table of some item couples, the matrix is not positive definite.
#This will accordingly apply to covariance matrices of model latent ability variables as well.

###

#2. ability-CFA

###

#2.1. prepare data: set matrices items as ordinal scaled
all_data[,c(grep("\\i_1_",names(all_data),val=T))] <- 
  lapply(all_data[,c(grep("\\i_1_",names(all_data),val=T))], ordered)

#2.2. measurement invariance: model estimations and comparisons:

###configural
configural<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7
'

configural_fit<-sem(configural, data= all_data, std.lv=F)
summary(configural_fit, fit.measures=T, standardized=T)


###weak

weak <-'

e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1

e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2

e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3

e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4

e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5

e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6

e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7
'

weak_fit<-sem(weak, data= all_data, std.lv=F)
summary(weak_fit, fit.measures=T, standardized=T)



###strong

strong<-'

e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1

e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2

e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3

e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4

e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5

e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6

e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#thresholds
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1

#means of latent variables
e1~1
e2~1
e3~1
e4~1
e5~1
e6~1
e7~1
'

strong_fit<-sem(strong, data= all_data, std.lv=F)
summary(strong_fit, fit.measures=T, standardized=T)

#2.3. comparisons via likelihood ratio tests
lrtests <- anova(configural_fit, weak_fit, strong_fit)
lrtests


###

#3. STA-CFA

###

#3.1. configural
fof_c <- '
fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

#specify the indicator specific latent variables to account for item specific covariances:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify model latent variable correlations:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 

errf9 ~~ 0.05*errf9
#This latent variable variance had to be restricted to 0.05 (value taken from the analysis with "all_data_subset")
#to avoid a heywood cases (negative variances) in model parameters. See Appendix B for further details.
'
fof_c_fit <- sem(fof_c, data= all_data, estimator= "MLR", std.lv=F)
summary(fof_c_fit, standardized=T, fit.measures=T)


#3.2. weak
fof_w <- '
fof1 =~ a*fam_5_1 + b*fam_9_1 + c*fam_12_1 + d*fam_16_1 + e*fam_18_1 
fof2 =~ a*fam_5_2 + b*fam_9_2 + c*fam_12_2 + d*fam_16_2 + e*fam_18_2 
fof3 =~ a*fam_5_3 + b*fam_9_3 + c*fam_12_3 + d*fam_16_3 + e*fam_18_3 
fof4 =~ a*fam_5_4 + b*fam_9_4 + c*fam_12_4 + d*fam_16_4 + e*fam_18_4 
fof5 =~ a*fam_5_5 + b*fam_9_5 + c*fam_12_5 + d*fam_16_5 + e*fam_18_5 
fof6 =~ a*fam_5_6 + b*fam_9_6 + c*fam_12_6 + d*fam_16_6 + e*fam_18_6 
fof7 =~ a*fam_5_7 + b*fam_9_7 + c*fam_12_7 + d*fam_16_7 + e*fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 

errf9 ~~ 0.05*errf9
#This latent variable variance had to be restricted to 0.05 (value taken from the analysis with "all_data_subset")
#to avoid heywood cases (negative variances) in model parameters. See Appendix B for further details.
'
fof_w_fit <- sem(fof_w, data= all_data, estimator= "MLR", std.lv =F)
summary(fof_w_fit, standardized=T, fit.measures=T)

#3.3. comparison via likelihood ratio test:
anova(fof_c_fit, fof_w_fit)


#3.4. Results, when the variance of the indicator specific latent variable of the second item (errf9)
#is freely estimated and heywood cases are accepted:

fof_c <- '
fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

#specify the indicator specific latent variables to account for item specific covariances:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify model latent variable correlations:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
'
fof_c_fit <- sem(fof_c, data= all_data, estimator= "MLR", std.lv=F)
summary(fof_c_fit, standardized=T, fit.measures=T)

fof_w <- '
fof1 =~ a*fam_5_1 + b*fam_9_1 + c*fam_12_1 + d*fam_16_1 + e*fam_18_1 
fof2 =~ a*fam_5_2 + b*fam_9_2 + c*fam_12_2 + d*fam_16_2 + e*fam_18_2 
fof3 =~ a*fam_5_3 + b*fam_9_3 + c*fam_12_3 + d*fam_16_3 + e*fam_18_3 
fof4 =~ a*fam_5_4 + b*fam_9_4 + c*fam_12_4 + d*fam_16_4 + e*fam_18_4 
fof5 =~ a*fam_5_5 + b*fam_9_5 + c*fam_12_5 + d*fam_16_5 + e*fam_18_5 
fof6 =~ a*fam_5_6 + b*fam_9_6 + c*fam_12_6 + d*fam_16_6 + e*fam_18_6 
fof7 =~ a*fam_5_7 + b*fam_9_7 + c*fam_12_7 + d*fam_16_7 + e*fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
'
fof_w_fit <- sem(fof_w, data= all_data, estimator= "MLR", std.lv =F)
summary(fof_w_fit, standardized=T, fit.measures=T)

anova(fof_c_fit, fof_w_fit)


#3.5. Results, when the indicator specific latent variable of the second item (errf9)
#is dismissed altogether:

fof_c <- '
fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

#specify the indicator specific latent variables to account for item specific covariances:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify model latent variable correlations:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
'
fof_c_fit <- sem(fof_c, data= all_data, estimator= "MLR", std.lv=F)
summary(fof_c_fit, standardized=T, fit.measures=T)

fof_w <- '
fof1 =~ a*fam_5_1 + b*fam_9_1 + c*fam_12_1 + d*fam_16_1 + e*fam_18_1 
fof2 =~ a*fam_5_2 + b*fam_9_2 + c*fam_12_2 + d*fam_16_2 + e*fam_18_2 
fof3 =~ a*fam_5_3 + b*fam_9_3 + c*fam_12_3 + d*fam_16_3 + e*fam_18_3 
fof4 =~ a*fam_5_4 + b*fam_9_4 + c*fam_12_4 + d*fam_16_4 + e*fam_18_4 
fof5 =~ a*fam_5_5 + b*fam_9_5 + c*fam_12_5 + d*fam_16_5 + e*fam_18_5 
fof6 =~ a*fam_5_6 + b*fam_9_6 + c*fam_12_6 + d*fam_16_6 + e*fam_18_6 
fof7 =~ a*fam_5_7 + b*fam_9_7 + c*fam_12_7 + d*fam_16_7 + e*fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
'
fof_w_fit <- sem(fof_w, data= all_data, estimator= "MLR", std.lv =F)
summary(fof_w_fit, standardized=T, fit.measures=T)

anova(fof_c_fit, fof_w_fit)



###

#4. interference reduction approach

###

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

#Warning: This analysis requires a lot of time and pc memory capacity. It might take up to 24 hours.
#Since the created lavaan-specific objects take up a lot of RAM, they will be frequently saved (via "save-image")
#and removed (via "rm") from workspace.
#It is highly recommended to save analysis results in a seperat text file, if you are not already doing so 
#(see beginning of script).:

# #create the text file "analysis_results" that will contain analysis results:
# zz <- file("analysis_results.txt", open = "wt")
# #specify that you want the outputs printed in that file
# sink(zz ,type = "output")
# #specify that you also want warning messages printed in that file
# sink(zz, type = "message")

#Some explanations:
#induce describes the complete interference model where interference effects induce measurement bias at every testsesison.
#inducex describes a more parsimonious interference model where interferences are only modeled up to test session x (1 to 6).
#induce0 discribes a model with only deficit but no interference effects.
#lr_induce_xy describes the likelihood ratio test between a model where interferences are modeled up to
#testsession x and a more parsimonious model where interference effects are only modeled up to testsession y = x-1.

induce<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 + i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 + i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 + i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce_fit<-sem(induce, data= all_data, std.lv=T)
summary(induce_fit, fit.measures=T, standardized=T)


induce6<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 + i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 + i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce6_fit<-sem(induce6, data= all_data, std.lv=T)
summary(induce6_fit, fit.measures=T, standardized=T)

lr_induce_76 <- anova(induce_fit, induce6_fit)
lr_induce_76


induce5<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 + i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce5_fit<-sem(induce5, data= all_data, std.lv=T)
summary(induce5_fit, fit.measures=T, standardized=T)

lr_induce_65 <- anova(induce6_fit, induce5_fit)
lr_induce_65

save.image("until5.rda")
rm("induce6_fit")


induce4<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 + i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce4_fit<-sem(induce4, data= all_data, std.lv=T)
summary(induce4_fit, fit.measures=T, standardized=T)

lr_induce_54 <- anova(induce5_fit, induce4_fit)
lr_induce_54

save.image("until4.rda")
rm("induce5_fit")


induce3<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 + i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce3_fit<-sem(induce3, data= all_data, std.lv=T)
summary(induce3_fit, fit.measures=T, standardized=T)

lr_induce_43 <- anova(induce4_fit, induce3_fit)
lr_induce_43

save.image("until3.rda")
rm("induce4_fit")


induce2<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 + i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce2_fit<-sem(induce2, data= all_data, std.lv=T)
summary(induce2_fit, fit.measures=T, standardized=T)

lr_induce_32 <- anova(induce3_fit, induce2_fit)
lr_induce_32

save.image("until2.rda")
rm("induce3_fit")


induce1<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 + i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce1_fit<-sem(induce1, data= all_data, std.lv=T)
summary(induce1_fit, fit.measures=T, standardized=T)

lr_induce_21 <- anova(induce2_fit, induce1_fit)
lr_induce_21

save.image("until1.rda")
rm("induce2_fit")


induce0<-'
#specify measurement of ability - factor loadings are kept constant across sessions:
e1 =~ m*i_1_1_1+ a*i_1_2_1+ b*i_1_3_1+ c*i_1_4_1+ d*i_1_5_1+ e*i_1_6_1+ f*i_1_7_1+ g*i_1_8_1+ h*i_1_9_1+ i*i_1_10_1+ j*i_1_11_1+ k*i_1_12_1+ l*i_1_13_1
e2 =~ m*i_1_1_2+ a*i_1_2_2+ b*i_1_3_2+ c*i_1_4_2+ d*i_1_5_2+ e*i_1_6_2+ f*i_1_7_2+ g*i_1_8_2+ h*i_1_9_2+ i*i_1_10_2+ j*i_1_11_2+ k*i_1_12_2+ l*i_1_13_2
e3 =~ m*i_1_1_3+ a*i_1_2_3+ b*i_1_3_3+ c*i_1_4_3+ d*i_1_5_3+ e*i_1_6_3+ f*i_1_7_3+ g*i_1_8_3+ h*i_1_9_3+ i*i_1_10_3+ j*i_1_11_3+ k*i_1_12_3+ l*i_1_13_3
e4 =~ m*i_1_1_4+ a*i_1_2_4+ b*i_1_3_4+ c*i_1_4_4+ d*i_1_5_4+ e*i_1_6_4+ f*i_1_7_4+ g*i_1_8_4+ h*i_1_9_4+ i*i_1_10_4+ j*i_1_11_4+ k*i_1_12_4+ l*i_1_13_4
e5 =~ m*i_1_1_5+ a*i_1_2_5+ b*i_1_3_5+ c*i_1_4_5+ d*i_1_5_5+ e*i_1_6_5+ f*i_1_7_5+ g*i_1_8_5+ h*i_1_9_5+ i*i_1_10_5+ j*i_1_11_5+ k*i_1_12_5+ l*i_1_13_5
e6 =~ m*i_1_1_6+ a*i_1_2_6+ b*i_1_3_6+ c*i_1_4_6+ d*i_1_5_6+ e*i_1_6_6+ f*i_1_7_6+ g*i_1_8_6+ h*i_1_9_6+ i*i_1_10_6+ j*i_1_11_6+ k*i_1_12_6+ l*i_1_13_6
e7 =~ m*i_1_1_7+ a*i_1_2_7+ b*i_1_3_7+ c*i_1_4_7+ d*i_1_5_7+ e*i_1_6_7+ f*i_1_7_7+ g*i_1_8_7+ h*i_1_9_7+ i*i_1_10_7+ j*i_1_11_7+ k*i_1_12_7+ l*i_1_13_7

#specify thresholds of matrices items to be constant across sessions:
i_1_1_1 | int1*t1
i_1_1_2 | int1*t1
i_1_1_3 | int1*t1
i_1_1_4 | int1*t1
i_1_1_5 | int1*t1
i_1_1_6 | int1*t1
i_1_1_7 | int1*t1

i_1_2_1 | int2*t1
i_1_2_2 | int2*t1
i_1_2_3 | int2*t1
i_1_2_4 | int2*t1
i_1_2_5 | int2*t1
i_1_2_6 | int2*t1
i_1_2_7 | int2*t1

i_1_3_1 | int3*t1
i_1_3_2 | int3*t1
i_1_3_3 | int3*t1
i_1_3_4 | int3*t1
i_1_3_5 | int3*t1
i_1_3_6 | int3*t1
i_1_3_7 | int3*t1

i_1_4_1 | int4*t1
i_1_4_2 | int4*t1
i_1_4_3 | int4*t1
i_1_4_4 | int4*t1
i_1_4_5 | int4*t1
i_1_4_6 | int4*t1
i_1_4_7 | int4*t1

i_1_5_1 | int5*t1
i_1_5_2 | int5*t1
i_1_5_3 | int5*t1
i_1_5_4 | int5*t1
i_1_5_5 | int5*t1
i_1_5_6 | int5*t1
i_1_5_7 | int5*t1

i_1_6_1 | int6*t1
i_1_6_2 | int6*t1
i_1_6_3 | int6*t1
i_1_6_4 | int6*t1
i_1_6_5 | int6*t1
i_1_6_6 | int6*t1
i_1_6_7 | int6*t1

i_1_7_1 | int7*t1
i_1_7_2 | int7*t1
i_1_7_3 | int7*t1
i_1_7_4 | int7*t1
i_1_7_5 | int7*t1
i_1_7_6 | int7*t1
i_1_7_7 | int7*t1

i_1_8_1 | int8*t1
i_1_8_2 | int8*t1
i_1_8_3 | int8*t1
i_1_8_4 | int8*t1
i_1_8_5 | int8*t1
i_1_8_6 | int8*t1
i_1_8_7 | int8*t1

i_1_9_1 | int9*t1
i_1_9_2 | int9*t1
i_1_9_3 | int9*t1
i_1_9_4 | int9*t1
i_1_9_5 | int9*t1
i_1_9_6 | int9*t1
i_1_9_7 | int9*t1

i_1_10_1 | int10*t1
i_1_10_2 | int10*t1
i_1_10_3 | int10*t1
i_1_10_4 | int10*t1
i_1_10_5 | int10*t1
i_1_10_6 | int10*t1
i_1_10_7 | int10*t1

i_1_11_1 | int11*t1
i_1_11_2 | int11*t1
i_1_11_3 | int11*t1
i_1_11_4 | int11*t1
i_1_11_5 | int11*t1
i_1_11_6 | int11*t1
i_1_11_7 | int11*t1

i_1_12_1 | int12*t1
i_1_12_2 | int12*t1
i_1_12_3 | int12*t1
i_1_12_4 | int12*t1
i_1_12_5 | int12*t1
i_1_12_6 | int12*t1
i_1_12_7 | int12*t1

i_1_13_1 | int13*t1
i_1_13_2 | int13*t1
i_1_13_3 | int13*t1
i_1_13_4 | int13*t1
i_1_13_5 | int13*t1
i_1_13_6 | int13*t1
i_1_13_7 | int13*t1


#Specify neighbor change-specifics (see:	Geiser, C. Data analysis with Mplus; The Guilford Press: New York, NY, USA, 2013):

#enter the latent difference variables:
diff2_1 =~ 0*i_1_1_1
diff3_2 =~ 0*i_1_1_1
diff4_3 =~ 0*i_1_1_1
diff5_4 =~ 0*i_1_1_1
diff6_5 =~ 0*i_1_1_1
diff7_6 =~ 0*i_1_1_1

#definition of latent difference variables by perfect regressions:
e2 ~ 1*e1 + 1*diff2_1
e2~~0*e2

e3 ~ 1*e1 + 1*diff2_1 + 1*diff3_2
e3~~0*e3

e4 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3
e4~~0*e4

e5 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4
e5~~0*e5

e6 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5
e6~~0*e6

e7 ~ 1*e1 + 1*diff2_1 + 1*diff3_2 + 1*diff4_3 + 1*diff5_4 + 1*diff6_5 + 1*diff7_6
e7~~0*e7

#specify zero-correlations between latent ability and latent difference variables:
e2~~0*e3
e2~~0*e4
e2~~0*e5
e2~~0*e6
e2~~0*e7
e2~~0*diff3_2
e2~~0*diff4_3
e2~~0*diff5_4
e2~~0*diff6_5
e2~~0*diff7_6

e3~~0*e4
e3~~0*e5
e3~~0*e6
e3~~0*e7
e3~~0*diff4_3
e3~~0*diff5_4
e3~~0*diff6_5
e3~~0*diff7_6

e4~~0*e5
e4~~0*e6
e4~~0*e7
e4~~0*diff5_4
e4~~0*diff6_5
e4~~0*diff7_6

e5~~0*e6
e5~~0*e7
e5~~0*diff6_5
e5~~0*diff7_6

e6~~0*e7
e6~~0*diff7_6

#estimate means of latent difference variables (and latent ability at the first test session):
e1~1
diff2_1~ md2_1*1
diff3_2~ md3_2*1
diff4_3~ md4_3*1
diff5_4~ md5_4*1
diff6_5~ md6_5*1
diff7_6~ md7_6*1

#estimate differences between means of latent difference variables to compare successive retest effects in size:
dr2_1 := md3_2 - md2_1
dr3_2 := md4_3 - md3_2
dr4_3 := md5_4 - md4_3
dr5_4 := md6_5 - md5_4
dr6_5 := md7_6 - md6_5

#specify the measurement of weak invariant STA model and interference effects:
fof1 =~ fi1*fam_5_1 + fi2*fam_9_1 + fi3*fam_12_1 + fi4*fam_16_1 + fi5*fam_18_1 
fof2 =~ fi1*fam_5_2 + fi2*fam_9_2 + fi3*fam_12_2 + fi4*fam_16_2 + fi5*fam_18_2 
fof3 =~ fi1*fam_5_3 + fi2*fam_9_3 + fi3*fam_12_3 + fi4*fam_16_3 + fi5*fam_18_3 
fof4 =~ fi1*fam_5_4 + fi2*fam_9_4 + fi3*fam_12_4 + fi4*fam_16_4 + fi5*fam_18_4 
fof5 =~ fi1*fam_5_5 + fi2*fam_9_5 + fi3*fam_12_5 + fi4*fam_16_5 + fi5*fam_18_5 
fof6 =~ fi1*fam_5_6 + fi2*fam_9_6 + fi3*fam_12_6 + fi4*fam_16_6 + fi5*fam_18_6 
fof7 =~ fi1*fam_5_7 + fi2*fam_9_7 + fi3*fam_12_7 + fi4*fam_16_7 + fi5*fam_18_7 

#specify indicator specific latent variables for the fof-items:
errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

#specify zero-correlations involving the indicator specific latent variables:
errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 

#specify deficit effects and zero correlations between latent STA variables on one side and latent ability variables and 
#latent difference variables on the other side:
fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 + 0*diff2_1 + 0*diff3_2 + 0*diff4_3 + 0*diff5_4 + 0*diff6_5 + 0*diff7_6 
'

induce0_fit<-sem(induce0, data= all_data, std.lv=T)
summary(induce0_fit, fit.measures=T, standardized=T)

lr_induce_10 <- anova(induce1_fit, induce0_fit)
lr_induce_10


save.image("until0.rda")


###

#5. comparing STA sum scores between the main study sample and high achievers (participants with ceiling effects)

###

#5.1 compute the grand fof sum score in both samples:
all_data_subset$fam_M_overall <- all_data_subset$fam_M_1 + 
  all_data_subset$fam_M_2 + 
  all_data_subset$fam_M_3 + 
  all_data_subset$fam_M_4 + 
  all_data_subset$fam_M_5 + 
  all_data_subset$fam_M_6 + 
  all_data_subset$fam_M_7 
all_data_ha$fam_M_overall <- all_data_ha$fam_M_1 + 
  all_data_ha$fam_M_2 + 
  all_data_ha$fam_M_3 + 
  all_data_ha$fam_M_4 + 
  all_data_ha$fam_M_5 + 
  all_data_ha$fam_M_6 + 
  all_data_ha$fam_M_7 

#5.2. one-tailed Welch tests for STA comparisons (every test session and grand)
t.test(all_data_ha$fam_M_1, all_data_subset$fam_M_1, "greater")
t.test(all_data_ha$fam_M_2, all_data_subset$fam_M_2, "greater")
t.test(all_data_ha$fam_M_3, all_data_subset$fam_M_3, "greater")
t.test(all_data_ha$fam_M_4, all_data_subset$fam_M_4, "greater")
t.test(all_data_ha$fam_M_5, all_data_subset$fam_M_5, "greater")
t.test(all_data_ha$fam_M_6, all_data_subset$fam_M_6, "greater")
t.test(all_data_ha$fam_M_7, all_data_subset$fam_M_7, "greater")
t.test(all_data_ha$fam_M_overall, all_data_subset$fam_M_overall, "greater")

#5.3. compute standard deviations of sum scores additionally
sd(all_data_subset$fam_M_1)
sd(all_data_subset$fam_M_2)
sd(all_data_subset$fam_M_3)
sd(all_data_subset$fam_M_4)
sd(all_data_subset$fam_M_5)
sd(all_data_subset$fam_M_6)
sd(all_data_subset$fam_M_7)
sd(all_data_subset$fam_M_overall)
sd(all_data_ha$fam_M_1)
sd(all_data_ha$fam_M_2)
sd(all_data_ha$fam_M_3)
sd(all_data_ha$fam_M_4)
sd(all_data_ha$fam_M_5)
sd(all_data_ha$fam_M_6)
sd(all_data_ha$fam_M_7)
sd(all_data_ha$fam_M_overall)


#####################################################################################################################
#####################################################################################################################

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#Before proceeding with the analyses given in Appendix C, you should clear your workspace and reload the data again:
rm(list=ls())
load("Data.rda")


#############################

### Appendix C: An alternative strategy for model identification in the interference reduction approach

#############################

###

#1. define the matrices items as ordinal again (for both data sets):

###
all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))] <- 
  lapply(all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))], ordered)
all_data[,c(grep("\\i_1_",names(all_data),val=T))] <- 
  lapply(all_data[,c(grep("\\i_1_",names(all_data),val=T))], ordered)


###

#2. interference reduction for the main study sample

###

induce<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 + e*i_1_1_5+ e*i_1_2_5+ e*i_1_3_5+ e*i_1_4_5+ e*i_1_5_5+ e*i_1_6_5+ e*i_1_7_5+ e*i_1_8_5+ e*i_1_9_5+ e*i_1_10_5+ e*i_1_11_5+ e*i_1_12_5+ e*i_1_13_5
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 + f*i_1_1_6+ f*i_1_2_6+ f*i_1_3_6+ f*i_1_4_6+ f*i_1_5_6+ f*i_1_6_6+ f*i_1_7_6+ f*i_1_8_6+ f*i_1_9_6+ f*i_1_10_6+ f*i_1_11_6+ f*i_1_12_6+ f*i_1_13_6
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 + g*i_1_1_7+ g*i_1_2_7+ g*i_1_3_7+ g*i_1_4_7+ g*i_1_5_7+ g*i_1_6_7+ g*i_1_7_7+ g*i_1_8_7+ g*i_1_9_7+ g*i_1_10_7+ g*i_1_11_7+ g*i_1_12_7+ g*i_1_13_7

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce_fit<-sem(induce, data= all_data_subset, std.lv=T)
summary(induce_fit, fit.measures=T, standardized=T)


induce6<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 + e*i_1_1_5+ e*i_1_2_5+ e*i_1_3_5+ e*i_1_4_5+ e*i_1_5_5+ e*i_1_6_5+ e*i_1_7_5+ e*i_1_8_5+ e*i_1_9_5+ e*i_1_10_5+ e*i_1_11_5+ e*i_1_12_5+ e*i_1_13_5
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 + f*i_1_1_6+ f*i_1_2_6+ f*i_1_3_6+ f*i_1_4_6+ f*i_1_5_6+ f*i_1_6_6+ f*i_1_7_6+ f*i_1_8_6+ f*i_1_9_6+ f*i_1_10_6+ f*i_1_11_6+ f*i_1_12_6+ f*i_1_13_6
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce6_fit<-sem(induce6, data= all_data_subset, std.lv=T)
summary(induce6_fit, fit.measures=T, standardized=T)

lr_induce_76 <- anova(induce_fit, induce6_fit)
lr_induce_76


induce5<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 + e*i_1_1_5+ e*i_1_2_5+ e*i_1_3_5+ e*i_1_4_5+ e*i_1_5_5+ e*i_1_6_5+ e*i_1_7_5+ e*i_1_8_5+ e*i_1_9_5+ e*i_1_10_5+ e*i_1_11_5+ e*i_1_12_5+ e*i_1_13_5
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce5_fit<-sem(induce5, data= all_data_subset, std.lv=T)
summary(induce5_fit, fit.measures=T, standardized=T)

lr_induce_65 <- anova(induce6_fit, induce5_fit)
lr_induce_65

save.image("until5.rda")
rm("induce6_fit")


induce4<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce4_fit<-sem(induce4, data= all_data_subset, std.lv=T)
summary(induce4_fit, fit.measures=T, standardized=T)

lr_induce_54 <- anova(induce5_fit, induce4_fit)
lr_induce_54

save.image("until4.rda")
rm("induce5_fit")


induce3<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce3_fit<-sem(induce3, data= all_data_subset, std.lv=T)
summary(induce3_fit, fit.measures=T, standardized=T)

lr_induce_43 <- anova(induce4_fit, induce3_fit)
lr_induce_43

save.image("until3.rda")
rm("induce4_fit")


induce2<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce2_fit<-sem(induce2, data= all_data_subset, std.lv=T)
summary(induce2_fit, fit.measures=T, standardized=T)

lr_induce_32 <- anova(induce3_fit, induce2_fit)
lr_induce_32

save.image("until2.rda")
rm("induce3_fit")


induce1<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce1_fit<-sem(induce1, data= all_data_subset, std.lv=T)
summary(induce1_fit, fit.measures=T, standardized=T)

lr_induce_21 <- anova(induce2_fit, induce1_fit)
lr_induce_21

save.image("until1.rda")
rm("induce2_fit")


induce0<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce0_fit<-sem(induce0, data= all_data_subset, std.lv=T)
summary(induce0_fit, fit.measures=T, standardized=T)

lr_induce_10 <- anova(induce1_fit, induce0_fit)
lr_induce_10

save.image("until0.rda")


###

#3. interference reduction for the data set including ceiling effects

###

#just to make sure that you have enough space in your workspace remove everything, load the data again
#and declare the matrices items as ordinal again:
rm(list=ls())
load("Data.rda")
all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))] <- 
  lapply(all_data_subset[,c(grep("\\i_1_",names(all_data_subset),val=T))], ordered)
all_data[,c(grep("\\i_1_",names(all_data),val=T))] <- 
  lapply(all_data[,c(grep("\\i_1_",names(all_data),val=T))], ordered)


induce<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 + e*i_1_1_5+ e*i_1_2_5+ e*i_1_3_5+ e*i_1_4_5+ e*i_1_5_5+ e*i_1_6_5+ e*i_1_7_5+ e*i_1_8_5+ e*i_1_9_5+ e*i_1_10_5+ e*i_1_11_5+ e*i_1_12_5+ e*i_1_13_5
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 + f*i_1_1_6+ f*i_1_2_6+ f*i_1_3_6+ f*i_1_4_6+ f*i_1_5_6+ f*i_1_6_6+ f*i_1_7_6+ f*i_1_8_6+ f*i_1_9_6+ f*i_1_10_6+ f*i_1_11_6+ f*i_1_12_6+ f*i_1_13_6
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 + g*i_1_1_7+ g*i_1_2_7+ g*i_1_3_7+ g*i_1_4_7+ g*i_1_5_7+ g*i_1_6_7+ g*i_1_7_7+ g*i_1_8_7+ g*i_1_9_7+ g*i_1_10_7+ g*i_1_11_7+ g*i_1_12_7+ g*i_1_13_7

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce_fit<-sem(induce, data= all_data, std.lv=T)
summary(induce_fit, fit.measures=T, standardized=T)


induce6<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 + e*i_1_1_5+ e*i_1_2_5+ e*i_1_3_5+ e*i_1_4_5+ e*i_1_5_5+ e*i_1_6_5+ e*i_1_7_5+ e*i_1_8_5+ e*i_1_9_5+ e*i_1_10_5+ e*i_1_11_5+ e*i_1_12_5+ e*i_1_13_5
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 + f*i_1_1_6+ f*i_1_2_6+ f*i_1_3_6+ f*i_1_4_6+ f*i_1_5_6+ f*i_1_6_6+ f*i_1_7_6+ f*i_1_8_6+ f*i_1_9_6+ f*i_1_10_6+ f*i_1_11_6+ f*i_1_12_6+ f*i_1_13_6
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce6_fit<-sem(induce6, data= all_data, std.lv=T)
summary(induce6_fit, fit.measures=T, standardized=T)

lr_induce_76 <- anova(induce_fit, induce6_fit)
lr_induce_76


induce5<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 + e*i_1_1_5+ e*i_1_2_5+ e*i_1_3_5+ e*i_1_4_5+ e*i_1_5_5+ e*i_1_6_5+ e*i_1_7_5+ e*i_1_8_5+ e*i_1_9_5+ e*i_1_10_5+ e*i_1_11_5+ e*i_1_12_5+ e*i_1_13_5
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce5_fit<-sem(induce5, data= all_data, std.lv=T)
summary(induce5_fit, fit.measures=T, standardized=T)

lr_induce_65 <- anova(induce6_fit, induce5_fit)
lr_induce_65

save.image("until5.rda")
rm("induce6_fit")


induce4<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 + d*i_1_1_4+ d*i_1_2_4+ d*i_1_3_4+ d*i_1_4_4+ d*i_1_5_4+ d*i_1_6_4+ d*i_1_7_4+ d*i_1_8_4+ d*i_1_9_4+ d*i_1_10_4+ d*i_1_11_4+ d*i_1_12_4+ d*i_1_13_4
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce4_fit<-sem(induce4, data= all_data, std.lv=T)
summary(induce4_fit, fit.measures=T, standardized=T)

lr_induce_54 <- anova(induce5_fit, induce4_fit)
lr_induce_54

save.image("until4.rda")
rm("induce5_fit")


induce3<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 + c*i_1_1_3+ c*i_1_2_3+ c*i_1_3_3+ c*i_1_4_3+ c*i_1_5_3+ c*i_1_6_3+ c*i_1_7_3+ c*i_1_8_3+ c*i_1_9_3+ c*i_1_10_3+ c*i_1_11_3+ c*i_1_12_3+ c*i_1_13_3
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce3_fit<-sem(induce3, data= all_data, std.lv=T)
summary(induce3_fit, fit.measures=T, standardized=T)

lr_induce_43 <- anova(induce4_fit, induce3_fit)
lr_induce_43

save.image("until3.rda")
rm("induce4_fit")


induce2<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 + b*i_1_1_2+ b*i_1_2_2+ b*i_1_3_2+ b*i_1_4_2+ b*i_1_5_2+ b*i_1_6_2+ b*i_1_7_2+ b*i_1_8_2+ b*i_1_9_2+ b*i_1_10_2+ b*i_1_11_2+ b*i_1_12_2+ b*i_1_13_2
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce2_fit<-sem(induce2, data= all_data, std.lv=T)
summary(induce2_fit, fit.measures=T, standardized=T)

lr_induce_32 <- anova(induce3_fit, induce2_fit)
lr_induce_32

save.image("until2.rda")
rm("induce3_fit")


induce1<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1 + a*i_1_1_1+ a*i_1_2_1+ a*i_1_3_1+ a*i_1_4_1+ a*i_1_5_1+ a*i_1_6_1+ a*i_1_7_1+ a*i_1_8_1+ a*i_1_9_1+ a*i_1_10_1+ a*i_1_11_1+ a*i_1_12_1+ a*i_1_13_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce1_fit<-sem(induce1, data= all_data, std.lv=T)
summary(induce1_fit, fit.measures=T, standardized=T)

lr_induce_21 <- anova(induce2_fit, induce1_fit)
lr_induce_21

save.image("until1.rda")
rm("induce2_fit")


induce0<-'

e1 =~ i_1_1_1+ i_1_2_1+ i_1_3_1+ i_1_4_1+ i_1_5_1+ i_1_6_1+ i_1_7_1+ i_1_8_1+ i_1_9_1+ i_1_10_1+ i_1_11_1+ i_1_12_1+ i_1_13_1

e2 =~ i_1_1_2+ i_1_2_2+ i_1_3_2+ i_1_4_2+ i_1_5_2+ i_1_6_2+ i_1_7_2+ i_1_8_2+ i_1_9_2+ i_1_10_2+ i_1_11_2+ i_1_12_2+ i_1_13_2

e3 =~ i_1_1_3+ i_1_2_3+ i_1_3_3+ i_1_4_3+ i_1_5_3+ i_1_6_3+ i_1_7_3+ i_1_8_3+ i_1_9_3+ i_1_10_3+ i_1_11_3+ i_1_12_3+ i_1_13_3

e4 =~ i_1_1_4+ i_1_2_4+ i_1_3_4+ i_1_4_4+ i_1_5_4+ i_1_6_4+ i_1_7_4+ i_1_8_4+ i_1_9_4+ i_1_10_4+ i_1_11_4+ i_1_12_4+ i_1_13_4

e5 =~ i_1_1_5+ i_1_2_5+ i_1_3_5+ i_1_4_5+ i_1_5_5+ i_1_6_5+ i_1_7_5+ i_1_8_5+ i_1_9_5+ i_1_10_5+ i_1_11_5+ i_1_12_5+ i_1_13_5

e6 =~ i_1_1_6+ i_1_2_6+ i_1_3_6+ i_1_4_6+ i_1_5_6+ i_1_6_6+ i_1_7_6+ i_1_8_6+ i_1_9_6+ i_1_10_6+ i_1_11_6+ i_1_12_6+ i_1_13_6

e7 =~ i_1_1_7+ i_1_2_7+ i_1_3_7+ i_1_4_7+ i_1_5_7+ i_1_6_7+ i_1_7_7+ i_1_8_7+ i_1_9_7+ i_1_10_7+ i_1_11_7+ i_1_12_7+ i_1_13_7

fof1 =~ fam_5_1 + fam_9_1 + fam_12_1 + fam_16_1 + fam_18_1
fof2 =~ fam_5_2 + fam_9_2 + fam_12_2 + fam_16_2 + fam_18_2 
fof3 =~ fam_5_3 + fam_9_3 + fam_12_3 + fam_16_3 + fam_18_3 
fof4 =~ fam_5_4 + fam_9_4 + fam_12_4 + fam_16_4 + fam_18_4 
fof5 =~ fam_5_5 + fam_9_5 + fam_12_5 + fam_16_5 + fam_18_5 
fof6 =~ fam_5_6 + fam_9_6 + fam_12_6 + fam_16_6 + fam_18_6 
fof7 =~ fam_5_7 + fam_9_7 + fam_12_7 + fam_16_7 + fam_18_7 

errf5  =~ fam_5_1 + fam_5_2 + fam_5_3 + fam_5_4 + fam_5_5 + fam_5_6 + fam_5_7 
errf9  =~ fam_9_1 + fam_9_2 + fam_9_3 + fam_9_4 + fam_9_5 + fam_9_6 + fam_9_7 
errf12 =~ fam_12_1 + fam_12_2 + fam_12_3 + fam_12_4 + fam_12_5 + fam_12_6 + fam_12_7 
errf16 =~ fam_16_1 + fam_16_2 + fam_16_3 + fam_16_4 + fam_16_5 + fam_16_6 + fam_16_7 
errf18 =~ fam_18_1 + fam_18_2 + fam_18_3 + fam_18_4 + fam_18_5 + fam_18_6 + fam_18_7 

errf5  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf9 + 0*errf12 + 0*errf16 + 0*errf18
errf9  ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf12 + 0*errf16 + 0*errf18
errf12 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf16 + 0*errf18
errf16 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 + 0*errf18
errf18 ~~ 0*fof1 + 0*fof2 + 0*fof3 + 0*fof4 + 0*fof5 + 0*fof6 + 0*fof7 
errf5  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf9  ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf12 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf16 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
errf18 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 

fof1 ~~ e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof2 ~~ 0*e1 + e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof3 ~~ 0*e1 + 0*e2 + e3 + 0*e4 + 0*e5 + 0*e6 + 0*e7 
fof4 ~~ 0*e1 + 0*e2 + 0*e3 + e4 + 0*e5 + 0*e6 + 0*e7 
fof5 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + e5 + 0*e6 + 0*e7 
fof6 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + e6 + 0*e7 
fof7 ~~ 0*e1 + 0*e2 + 0*e3 + 0*e4 + 0*e5 + 0*e6 + e7 
'

induce0_fit<-sem(induce0, data= all_data, std.lv=T)
summary(induce0_fit, fit.measures=T, standardized=T)

lr_induce_10 <- anova(induce1_fit, induce0_fit)
lr_induce_10

save.image("until0.rda")



